@@ -1,3 +1,3 @@
-from quickhttp.quickhttp import app
+from quickhttp.cli import app
 
 app(prog_name="python -m quickhttp")
